# line-intersect-2d

[![PyPI](https://img.shields.io/pypi/pyversions/line-intersect-2d.svg)](https://pypi.python.org/pypi/line-intersect-2d)
[![PyPI version](https://badge.fury.io/py/line-intersect-2d.svg)](https://badge.fury.io/py/line-intersect-2d)
[![PyPI](https://img.shields.io/pypi/implementation/line-intersect-2d.svg)](https://pypi.python.org/pypi/line-intersect-2d)
[![Documentation Status](https://readthedocs.org/projects/line-intersect-2d/badge/?version=latest)](http://line-intersect-2d.readthedocs.io/en/latest/?badge=latest)
[![Maintainability](https://api.codeclimate.com/v1/badges/657b03d115f6e001633c/maintainability)](https://codeclimate.com/github/Cervi-Robotics/line-intersect-2d/maintainability)
[![Build status](https://circleci.com/gh/Cervi-Robotics/line-intersect-2d.svg?style=shield)](https://app.circleci.com/pipelines/github/Cervi-Robotics/line-intersect-2d)

A Cython module to check if two paths in 2D intersect
